Helioviewer Python API Wrapper
------------------------------

|Latest Version| |codecov|

.. |Latest Version| image:: https://img.shields.io/pypi/v/hvpy.svg
   :target: https://pypi.python.org/pypi/hvpy/
.. |codecov| image:: https://codecov.io/gh/Helioviewer-Project/python-api/branch/main/graph/badge.svg
   :target: https://app.codecov.io/gh/Helioviewer-Project/python-api/

``hvpy`` is a Python API wrapper around the formal `Helioviewer API <https://api.helioviewer.org/docs/v2/>`__.

`Python API documentation <https://hvpy.readthedocs.io/en/latest/>`__

This work was supported by the `2022 Google Summer of Code <https://summerofcode.withgoogle.com/>`__, the `SunPy Project <https://sunpy.org>`__, and the `Helioviewer Project <https://github.com/Helioviewer-Project/>`__.
